import { PublishParameters, PublishResult, GetContextParameters, GetContextResult, ISearchResults, CreateFolderParameters, MoveParameters, IActionResult, TrashParameters, CreateFolderResult, UpdateFolderParameters, ID, GetSubFoldersResult, DeleteParameters, ResourceType } from "..";
import { OdeServices } from "../services/OdeServices";
import { CreateParameters, CreateResult, UpdateParameters, UpdateResult } from "./interface";
export declare abstract class ResourceService {
    protected context: OdeServices;
    private static registry;
    static register({ application, resourceType, }: {
        application: string;
        resourceType: string;
    }, service: (context: OdeServices) => ResourceService): void;
    static findService({ application, resourceType, }: {
        application: string;
        resourceType: string;
    }, context: OdeServices): ResourceService;
    static findMainService({ application }: {
        application: string;
    }, context: OdeServices): ResourceService;
    constructor(context: OdeServices);
    protected get http(): import("../transport/Service").HttpService;
    abstract getApplication(): string;
    abstract getPrintUrl(resourceId: string, withComment?: boolean): string;
    abstract getViewUrl(resourceId: string): string;
    abstract getFormUrl(folderId?: string): string;
    abstract create<T extends CreateParameters>(parameters: T): Promise<CreateResult>;
    abstract update<T extends UpdateParameters>(parameters: T): Promise<UpdateResult>;
    abstract getResourceType(): ResourceType;
    getShareReadUrl(id: string): string;
    getSaveShareUrl(id: string): string;
    gotoPrint(resourceId: string, withComment?: boolean): void;
    gotoView(resourceId: string): void;
    gotoForm(folderId?: string): void;
    publish(parameters: PublishParameters): Promise<PublishResult>;
    /** Create a search context. */
    createContext(parameters: GetContextParameters): Promise<GetContextResult>;
    /** Search / paginate within a search context. */
    searchContext(parameters: GetContextParameters): Promise<ISearchResults>;
    /** Create a new folder. */
    createFolder(parameters: CreateFolderParameters): Promise<CreateFolderResult>;
    /** Update folder. */
    updateFolder(parameters: UpdateFolderParameters): Promise<CreateFolderResult>;
    /** Move resources/folders to a folder. */
    moveToFolder(parameters: MoveParameters): Promise<IActionResult>;
    /** List subfolders of a parent folder. */
    listSubfolders(folderId: ID): Promise<GetSubFoldersResult>;
    /** Delete folders and/or resources. */
    deleteAll(parameters: DeleteParameters): Promise<IActionResult>;
    /** Trash folders and/or resources. */
    trashAll({ resourceType, ...parameters }: Omit<TrashParameters, "trash">): Promise<IActionResult>;
    /** Trash folders and/or resources. */
    restoreAll({ resourceType, ...parameters }: Omit<TrashParameters, "trash">): Promise<IActionResult>;
    protected checkHttpResponse: <R>(result: R) => R;
    protected getThumbnailPath(thumb: string | Blob | File | undefined): Promise<string | undefined>;
    private toQueryParams;
    private createFolderToBodyParams;
    private moveToBodyParams;
}
